from django.contrib import admin

from .models import GenericGroup

# admin.site.register(GenericGroup)

